OpenSCM-Units
=============

+----------------+-----------------+
| |CI CD|        | |PyPI Install|  |
+----------------+-----------------+
| |PyPI|         | |PyPI Version|  |
+----------------+-----------------+

Brief summary
+++++++++++++

.. sec-begin-long-description
.. sec-begin-index

OpenSCM-Units is a repository for handling of units related to simple climate modelling.

.. sec-end-index

License
-------

.. sec-begin-license

OpenSCM-Units is free software under a BSD 3-Clause License, see
`LICENSE <https://github.com/openscm-project/openscm-units/blob/master/LICENSE>`_.

.. sec-end-license
.. sec-end-long-description

.. sec-begin-installation

Installation
------------

OpenSCM-Runner can be installed with pip

.. code:: bash

    pip install openscm-units

If you also want to run the example notebooks install additional
dependencies using

.. code:: bash

    pip install openscm-units[notebooks]

**Coming soon** OpenSCM-Units can also be installed with conda

.. code:: bash

    conda install -c conda-forge openscm-units

.. sec-end-installation

Documentation
-------------

Documentation can be found at our `documentation pages <https://openscm-units.readthedocs.io/en/latest/>`_
(we are thankful to `Read the Docs <https://readthedocs.org/>`_ for hosting us).

Contributing
------------

Please see the `Development section of the docs <https://openscm-units.readthedocs.io/en/latest/development.html>`_.

.. sec-begin-links

.. |CI CD| image:: https://github.com/openscm-project/openscm-units/workflows/OpenSCM-Units%20CI-CD/badge.svg
    :target: https://github.com/openscm-project/openscm-units/actions?query=workflow%3A%22OpenSCM-Units+CI-CD%22
.. |PyPI Install| image:: https://github.com/openscm-project/openscm-units/workflows/Test%20PyPI%20install/badge.svg
    :target: https://github.com/openscm-project/openscm-units/actions?query=workflow%3A%22Test+PyPI+install%22
.. |PyPI| image:: https://img.shields.io/pypi/pyversions/openscm-units.svg
    :target: https://pypi.org/project/openscm-units/
.. |PyPI Version| image:: https://img.shields.io/pypi/v/openscm-units.svg
    :target: https://pypi.org/project/openscm-units/

.. sec-end-links
